* The Fiscally Moderate Italian Populist Voter: Evidence from a Survey Experiment
* Party Politics
* 2018
* Franchino, Fabio and Fedra Negri

* Figure 1: Marginal effects of programme attributes, conditional on 2013 vote choice, and compared to M5S voters
* Euro - left panel

version 14
use data.dta, clear

* the dataset excludes respondents who did/could not vote at the 2013 national elections and those who did not respond
* vote choice at the 2013 national elections 
tab VC_D060
label list VC_D060

* regression (reference category is the one with the highest frequency: PD voters)
reg Y1 i.unemployment##ib(freq).VC_D060 i.inflation##ib(freq).VC_D060 i.taxsoc##ib(freq).VC_D060 ///
i.euro##ib(freq).VC_D060 i.eucontrol##ib(freq).VC_D060 i.eutaxsoc##ib(freq).VC_D060, cl(ID) 

*saving estimates
estimates save m.ster, replace

* saving matrix of coefficients
matrix b=e(b)
matrix list b

* saving matrix of results
margins, over(VC_D060) dydx(euro)
matrix r = r(table)'
matrix list r
drop _all
svmat r , names(col) 

* measure variable
gen meas=1 in 1/9
replace meas=2 in 10/18

* party variable
gen py=_n in 1/9
replace py=_n-9 in 10/18

* delete observations (keep only meas 2 - ditch the euro - and exclude party = 9 - other parties)
drop if py==9
keep if meas==2

sort py meas

gen MV = _n

eclplot b ul ll MV, hor estopts(msize(small)) rplottype(rspike) ciopts(msize(small)) graphregion(fcolor(white)) ysca(noline) ///
xtitle("") ytitle("") ylabel(1 "RC" 2 "SEL" 3 "PD" 4 "{bf:M5S}" 5 "Monti List" 6 "FARE" 7 "PdL" 8 "LN & FdI", noticks nogrid labsize(3)) ///
xline(0, lcolor(black) lwidth(medthin)) saving(FIGURE1_euro_l, replace) title("Conditional on vote choice", size(3))

* The Fiscally Moderate Italian Populist Voter: Evidence from a Survey Experiment
* Party Politics
* 2018
* Franchino, Fabio and Fedra Negri

* Figure 1: Marginal effects of programme attributes, conditional on 2013 vote choice, and compared to M5S voters
* Euro - right panel

**********   EURO drop vs keep (baseline) & M5S vs Civil Revolution
estimates use m.ster
est des
preserve
drawnorm MG_b1-MG_b200, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
generate x_betahat0 = MG_b131
generate x_betahat1 = MG_b134
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
display ""
postclose mypost
use sim.dta, clear
save sim2.dta, replace
restore, not

**********   EURO drop vs keep (baseline) & M5S vs SEL
estimates use m.ster
est des
preserve
drawnorm MG_b1-MG_b200, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
generate x_betahat0 = MG_b132
generate x_betahat1 = MG_b134
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
display ""
postclose mypost
use sim2.dta, clear
append using sim.dta
save sim2.dta, replace
restore, not

**********   EURO drop vs keep (baseline) & M5S vs PD (baseline)
estimates use m.ster
est des
preserve
drawnorm MG_b1-MG_b200, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
generate x_betahat0 = MG_b133
generate x_betahat1 = MG_b134
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
display ""
postclose mypost
use sim2.dta, clear
append using sim.dta
save sim2.dta, replace
restore, not

**********   EURO drop vs keep (baseline) & M5S vs Monti
estimates use m.ster
est des
preserve
drawnorm MG_b1-MG_b200, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
generate x_betahat0 = MG_b135
generate x_betahat1 = MG_b134
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
display ""
postclose mypost
use sim2.dta, clear
append using sim.dta
save sim2.dta, replace
restore, not

**********   EURO drop vs keep (baseline) & M5S vs FARE
estimates use m.ster
est des
preserve
drawnorm MG_b1-MG_b200, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
generate x_betahat0 = MG_b136
generate x_betahat1 = MG_b134
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
display ""
postclose mypost
use sim2.dta, clear
append using sim.dta
save sim2.dta, replace
restore, not

**********   EURO drop vs keep (baseline) & M5S vs PdL
estimates use m.ster
est des
preserve
drawnorm MG_b1-MG_b200, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
generate x_betahat0 = MG_b137
generate x_betahat1 = MG_b134
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
display ""
postclose mypost
use sim2.dta, clear
append using sim.dta
save sim2.dta, replace
restore, not

**********   EURO drop vs keep (baseline) & M5S vs LN/FdI
estimates use m.ster
est des
preserve
drawnorm MG_b1-MG_b200, n(10000) means(e(b)) cov(e(V)) clear seed(1)
postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim.dta, replace
noisily display "start"
generate x_betahat0 = MG_b138
generate x_betahat1 = MG_b134
gen prob0=normal(x_betahat0)
gen prob1=normal(x_betahat1)
gen diff=prob1-prob0
egen probhat0=mean(prob0)
egen probhat1=mean(prob1)
egen diffhat=mean(diff)
tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi   
_pctile prob0, p(2.5,97.5) 
scalar `lo0' = r(r1)
scalar `hi0' = r(r2)  
_pctile prob1, p(2.5,97.5)
scalar `lo1'= r(r1)
scalar `hi1'= r(r2)  
_pctile diff, p(2.5,97.5)
scalar `diff_lo'= r(r1)
scalar `diff_hi'= r(r2)  
scalar `prob_hat0'=probhat0
scalar `prob_hat1'=probhat1
scalar `diff_hat'=diffhat
post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat 
display ""
postclose mypost
use sim2.dta, clear
append using sim.dta
save sim2.dta, replace
restore, not

use sim2.dta, clear
gen MV = _n
eclplot diff_hat diff_hi diff_lo MV, hor estopts(msize(small)) rplottype(rspike) ciopts(msize(small)) graphregion(fcolor(white)) ysca(noline) ///
xtitle("") ytitle("") ylabel(1 "RC" 2 "SEL" 3 "PD" 4 "Monti List" 5 "FARE" 6 "PdL" 7 "LN & FdI", noticks nogrid labsize(3)) ///
xline(0, lcolor(black) lwidth(medthin)) saving(FIGURE1_euro_r, replace) title("M5S voters compared", size(3))

gr combine FIGURE1_euro_l.gph FIGURE1_euro_r.gph, title(Ditching the euro, size(3)) graphregion(fcolor(white)) saving(FIGURE1_euro, replace)

